# power_digit_additions

#Please enter Base Number
2

#Please enter Exponent Number
11

#You have entered expression:	pow(2, 11)
#Result of given expression is:	2048
#Addition of digits of a number 2048 is 5
